@@ -9,7 +9,6 @@ try:
 except ImportError:
     from collections import MutableMapping
 
-
 APP_SETTINGS = {
     "theme": "light",
     "pin_menu": False,
@@ -175,10 +174,10 @@ class DefaultStore(object):
         data_id = int(data_id)
         return self._data_store.get(data_id)
 
-    def new_data_inst(self, data_id=None):
+    def new_data_inst(self, data_id=None, instance=None):
         if data_id is None:
             data_id = self.build_data_id()
-        new_data = DtaleInstance(None)
+        new_data = instance or DtaleInstance(None)
         data_id = int(data_id)
         self._data_store[data_id] = new_data
         return data_id
@@ -187,9 +186,15 @@ class DefaultStore(object):
         return self.get_data_inst(data_id).data
 
     def get_data_id_by_name(self, data_name):
-        if data_name not in self._data_names:
-            return None
-        return self._data_names[data_name]
+        data_id = next(
+            (
+                value
+                for key, value in self._data_names.items()
+                if convert_name_to_url_path(key) == data_name or key == data_name
+            ),
+            None,
+        )
+        return data_id
 
     def get_dataset(self, data_id):
         return self.get_data_inst(data_id).dataset
@@ -325,7 +330,7 @@ def drop_punctuation(val):
 def convert_name_to_url_path(name):
     if name is None:
         return None
-    url_name = drop_punctuation(name)
+    url_name = drop_punctuation("{}".format(name))
     url_name = url_name.lower()
     return "_".join(url_name.split(" "))
 
@@ -378,14 +383,27 @@ def cleanup(data_id=None):
         _default_store.delete_instance(data_id)
 
 
+def update_id(old_data_id, new_data_id):
+    if _default_store.contains(new_data_id):
+        raise Exception("Data already exists for id ({})".format(new_data_id))
+    curr_data = _default_store.get_data_inst(old_data_id)
+    _default_store.delete_instance(old_data_id)
+    data_id = int(new_data_id)
+    _default_store.new_data_inst(data_id, curr_data)
+    return data_id
+
+
 def load_flag(data_id, flag_name, default):
     import dtale
 
+    app_settings = get_app_settings()
     curr_settings = get_settings(data_id) or {}  # noqa: F821
     global_flag = getattr(dtale, flag_name.upper())
     if global_flag != default:
         return global_flag
-    return curr_settings.get(flag_name, default)
+    if flag_name in app_settings and app_settings[flag_name] != default:
+        return app_settings[flag_name]
+    return curr_settings.get(flag_name, app_settings.get(flag_name, default))
 
 
 def _as_dict(store):
